@@ -70,7 +70,7 @@ class Aliyun:
         auto_release_hour = self.context.get_root_config('auto_release_hour')
         auto_release_at = None
         if auto_release_hour is not None:
-            auto_release_at = datetime.datetime.utcnow() + datetime.timedelta(hours=auto_release_hour)
+            auto_release_at = datetime.utcnow() + timedelta(hours=auto_release_hour)
             auto_release_at = auto_release_at.isoformat(timespec='seconds') + "Z"
 
         request = RunInstancesRequest()
